@@ -8,10 +8,12 @@ import os
 import threading
 from random import randrange
 from time import sleep, time
+
 import cv2
 from PyQt5.QtCore import pyqtProperty, pyqtSlot, pyqtSignal
 from PyQt5.QtQuick import QQuickItem
 from pyffmpeg import FFmpeg
+
 from .pyqt_inter_audio import QAudio
 
 
@@ -53,8 +55,16 @@ class QVideo(QQuickItem):
         self._cv2_frames_len = 0
         self._cv2_tmp_frames_len = 0
         self._cv2_session = False
+        # Qml property
+        self._current_frame = ''
+        self._aspect_ratio = True
+        self._tile = 0
+        self._tile_enumeration = False
 
     frameUpdate = pyqtSignal(str, arguments=['updateFrame'])
+    aspectRatioChanged = pyqtSignal(bool, arguments=['aspectRatio'])
+    tileChanged = pyqtSignal(int, arguments=['tileChange'])
+    tileEnumChanged = pyqtSignal(bool, arguments=['tileEnum'])
     destroyed = pyqtSignal()
 
     @pyqtSlot()
@@ -95,7 +105,15 @@ class QVideo(QQuickItem):
         self._current_frame = ''
         self.updateFrame('')
 
-    @pyqtProperty('QString')
+    @pyqtProperty(bool, notify=aspectRatioChanged)
+    def aspectRatio(self):
+        return self._aspect_ratio
+
+    @aspectRatio.setter
+    def aspectRatio(self, value):
+        self._aspect_ratio = value
+
+    @pyqtProperty('QString', notify=frameUpdate)
     def currentFrame(self):
         return self._current_frame
 
@@ -103,6 +121,24 @@ class QVideo(QQuickItem):
     def currentFrame(self, frame):
         self._current_frame = frame
 
+    @pyqtProperty(int, notify=tileChanged)
+    def tile(self):
+        return self._tile
+
+    @tile.setter
+    def tile(self, value):
+        self._tile = value
+        if self._tile > 2 and self._tile < 6:
+            self._tile_enumeration = value
+
+    @pyqtProperty(int, notify=tileEnumChanged)
+    def tileEnumeration(self):
+        return self._tile_enumeration
+
+    @tileEnumeration.setter
+    def tileEnumeration(self, value):
+        pass
+
     def convert_to_stills(self, fileName):
         """
         convert the video files to stills
@@ -151,7 +187,7 @@ class QVideo(QQuickItem):
         u_thread = threading.Thread(target = self._pause)
         u_thread.daemon = True
         u_thread.start()
-    
+
     def _pause(self):
         self._paused = True
 
@@ -160,7 +196,7 @@ class QVideo(QQuickItem):
         u_thread = threading.Thread(target = self._resume)
         u_thread.daemon = True
         u_thread.start()
-    
+
     def _resume(self):
         self._paused = False
 
@@ -168,7 +204,7 @@ class QVideo(QQuickItem):
         u_thread = threading.Thread(target = self._monitor)
         u_thread.daemon = True
         u_thread.start()
-    
+
     def _monitor(self):
         total = 0
         prev = 0
@@ -358,14 +394,12 @@ class QVideo(QQuickItem):
             else:
                 sleep(1/10)
 
-
         # stop showing the last frame
         self._current_frame = ''
         self.updateFrame('')
-        
+
         self._stopped = True  # stop all other processs; will cause no trouble
         self._cv2_session = False
 
-
     def updateFrame(self, frame):
         self.frameUpdate.emit(frame)
